@@ -5,7 +5,7 @@ use warnings;
 use utf8;
 use Regexp::Grammars;
 
-our $VERSION = '0.39';
+our $VERSION = '0.44';
 
 sub new {
 	my ($class) = @_;
@@ -886,7 +886,7 @@ sub PT::CalcExpression::X {
     }
 
     my $calcExpression = $calcOperands[0];
-    for my $counter (1..$#calcOperands) {
+    for my $counter (1 .. $#calcOperands) {
         $calcExpression .= $calcOperator[$counter - 1] . " " . $calcOperands[$counter];
     }
 
@@ -1193,7 +1193,8 @@ sub parse {
         my $code = $/{Lang}->X();
         return $code;
     } else {
-        print "Not matched";
+        my $notMatch = "print 'not valid source';";
+		return $notMatch;
     }
 }
 
